@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+"""This module contains functions to replay a sequence of user actions automatically."""
 
 # print('__file__={0:<35} | __name__={1:<20} | __package__={2:<20}'.format(__file__, __name__, str(__package__)))
 from .core import *
